@@ -82,7 +82,7 @@ function getSriovInfoJson(bool $includeVfDetails = true): string {
             $vf_pci = basename(readlink($vf));
             $vf_entry = ['pci' => $vf_pci];
             // Device class + numeric class + name
-            [$class, $class_id, $name] = getPciClassNameAndId($vf_pci);
+            [$vfclass, $vfclass_id, $vfname] = getPciClassNameAndId($vf_pci);
             if ($includeVfDetails) {
                 // Vendor:Device formatted string
                 $vendorFile = "/sys/bus/pci/devices/{$vf_pci}/vendor";
@@ -90,8 +90,8 @@ function getSriovInfoJson(bool $includeVfDetails = true): string {
                 $vendor = is_readable($vendorFile) ? trim(file_get_contents($vendorFile)) : null;
                 $device = is_readable($deviceFile) ? trim(file_get_contents($deviceFile)) : null;
                 $vf_entry['vd'] = ($vendor && $device) ? sprintf('%s:%s', substr($vendor, 2), substr($device, 2)) : null;
-                $vf_entry['class'] = $class;
-                $vf_entry['class_id'] = $class_id;
+                $vf_entry['class'] = $vfclass;
+                $vf_entry['class_id'] = $vfclass_id;
                 // Network interface info
                 $net = glob("/sys/bus/pci/devices/{$vf_pci}/net/*");
                 if ($net && isset($net[0])) {
